@@ -427,6 +427,25 @@ def get_execution_data(runtime: EngineRuntimeInterface, node_id: str) -> EngineA
     return {"inputs": data.inputs, "outputs": data.outputs}
 
 
+@_ensure_return_api_result
+def get_data(runtime: EngineRuntimeInterface, node_id: str) -> EngineAPIResult:
+    """
+    获取某个节点的原始输入数据
+
+    :param runtime: 引擎运行时实例
+    :type runtime: EngineRuntimeInterface
+    :param node_id: 节点 ID
+    :type node_id: str
+    :return: 执行结果
+    :rtype: EngineAPIResult
+    """
+    data = runtime.get_data(node_id)
+    return {
+        "inputs": {k: {"need_render": v.need_render, "value": v.value} for k, v in data.inputs.items()},
+        "outputs": data.outputs,
+    }
+
+
 @_ensure_return_api_result
 def get_node_histories(runtime: EngineRuntimeInterface, node_id: str, loop: int = -1) -> EngineAPIResult:
     """
@@ -564,12 +583,7 @@ def preview_node_inputs(
     """
     total_constants = {**current_constants, **pipeline["data"].get("inputs", {})}
     context_values = [
-        ContextValue(
-            key=key,
-            type=VAR_CONTEXT_MAPPING[info["type"]],
-            value=info["value"],
-            code=info.get("custom_type")
-        )
+        ContextValue(key=key, type=VAR_CONTEXT_MAPPING[info["type"]], value=info["value"], code=info.get("custom_type"))
         for key, info in total_constants.items()
     ]
     context = Context(runtime, context_values, root_pipeline_data)
