@@ -222,7 +222,7 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_retrun_process_id(state)
+        process_id = self._ensure_state_is_fail_and_return_process_id(state)
 
         self.runtime.pre_retry_node(node_id, data)
 
@@ -266,7 +266,7 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_retrun_process_id(state)
+        process_id = self._ensure_state_is_fail_and_return_process_id(state)
 
         self.runtime.pre_skip_node(node_id)
 
@@ -308,7 +308,7 @@ class Engine:
 
         state = self.runtime.get_state(node_id)
 
-        process_id = self._ensure_state_is_fail_and_retrun_process_id(state)
+        process_id = self._ensure_state_is_fail_and_return_process_id(state)
 
         self.runtime.pre_skip_exclusive_gateway(node_id, flow_id)
 
@@ -663,8 +663,10 @@ class Engine:
         :param callback_data_id: 回调数据 ID, defaults to None
         :type callback_data_id: Optional[int], optional
         """
+        root_pipeline_id = ""
         try:
             process_info = self.runtime.get_process_info(process_id)
+            root_pipeline_id = process_info.root_pipeline_id
 
             # try to get lock
             lock_get = self.runtime.apply_schedule_lock(schedule_id)
@@ -673,7 +675,7 @@ class Engine:
                 try_after = random.randint(1, 5)
                 logger.info(
                     "[%s] schedule(%s) lock %s with data %s fetch fail, try after %s",
-                    process_info.root_pipeline_id,
+                    root_pipeline_id,
                     node_id,
                     schedule_id,
                     callback_data_id,
@@ -703,7 +705,7 @@ class Engine:
                 if state.version != schedule.version:
                     logger.info(
                         "[%s] schedule(%s) %s with version %s expired, current version: %s",
-                        process_info.root_pipeline_id,
+                        root_pipeline_id,
                         schedule_id,
                         node_id,
                         schedule.version,
@@ -716,7 +718,7 @@ class Engine:
                 if state.name != states.RUNNING:
                     logger.info(
                         "[%s] schedule(%s) %s state is not running: %s",
-                        process_info.root_pipeline_id,
+                        root_pipeline_id,
                         schedule_id,
                         node_id,
                         state.name,
@@ -739,7 +741,7 @@ class Engine:
 
                 logger.info(
                     "[%s] before schedule node %s with data %s",
-                    process_info.root_pipeline_id,
+                    root_pipeline_id,
                     node,
                     callback_data,
                 )
@@ -762,7 +764,7 @@ class Engine:
             ex_data = traceback.format_exc()
             logger.warning(
                 "[%s]schedule exception catch at node(%s): %s",
-                process_info.root_pipeline_id,
+                root_pipeline_id,
                 node_id,
                 ex_data,
             )
@@ -770,13 +772,14 @@ class Engine:
             if isinstance(e, StateVersionNotMatchError):
                 logger.exception(
                     "[%s]schedule exception catch StateVersionNotMatchError at node(%s): %s",
-                    process_info.root_pipeline_id,
+                    root_pipeline_id,
                     node_id,
                     ex_data,
                 )
                 return
 
-            # make sure release_schedule_lock call at first, because remain operations may have been completed in execute
+            # make sure release_schedule_lock call at first,
+            # because remain operations may have been completed in execute
             self.runtime.release_schedule_lock(schedule_id)
 
             outputs = self.runtime.get_execution_data_outputs(node_id)
@@ -815,7 +818,7 @@ class Engine:
             outputs=exec_data.outputs,
         )
 
-    def _ensure_state_is_fail_and_retrun_process_id(self, state: State) -> str:
+    def _ensure_state_is_fail_and_return_process_id(self, state: State) -> str:
         if state.name != states.FAILED:
             raise InvalidOperationError("{} state is not FAILED, actual {}".format(state.node_id, state.name))
 
